<?php
/**
 * This file implements the ShareThis plugin.
 *
 * For the most recent and complete Plugin API documentation
 * see {@link Plugin} in ../evocore/_plugin.class.php.
 *
 * @package plugins
 *
 * {@internal Below is a list of authors who have contributed to design/coding of this file: }}
 * @author jrusso: Jaromy Russo - (@link http://www.jaromy.net/}
 * @version $Id: _sharethis.plugin.php,v 1.0 2009/02/17 12:40:08 jrusso Exp $
 *
 * Revision Notes:
 *	02/17/2009	1.0		JJR		Plugin created
 *	03/07/2009	1.1		JJR		Fixed error with checking empty $Item - if widget is placed in non-Post container,
 *								then $item will not exist; use Blog Title & URL in that case.
 */
if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );


/**
 * Blogalaxia_Tags Plugin
 *
 * This plugin responds to virtually all possible plugin events :P
 *
 * @package plugins
 */
class sharethiswidget_plugin extends Plugin
{
	/**
	 * Variables below MUST be overriden by plugin implementations,
	 * either in the subclass declaration or in the subclass constructor.
	 */
	var $name = 'ShareThis Widget';
	var $code = 'b2ShareThis';
	var $priority = 99;
	var $version = '1.1';
	var $group = 'widget';
	var $author = 'Jaromy Russo';
	var $help_url = '';  // empty URL defaults to manual wiki


	/*
	 * These variables MAY be overriden.
	 */
	var $apply_rendering = 'never';
	var $number_of_installs = 1;


	/**
	 * Init
	 *
	 * This gets called after a plugin has been registered/instantiated.
	 */
	function PluginInit( & $params )
	{
		$this->short_desc = T_('Add a ShareThis link in your blog');
		$this->long_desc = T_('This plug-in adds a ShareThis Widget in your blog. ShareThis enables the user to send a post to a variety of social websites. This plug-in exists in Widget form, so the user can add it to his/her blog by using the b2evo backoffice admin area to place it in the desired skin container.  Originally based upon the ShareThis Plugin written by Larry Nieves.');
	}

	function  GetDefaultSettings()
	{
	return array(
	  'publisher' => array(
		'label' => T_( 'ShareThis publisher ID' ),
		'defaultvalue' => '',
		'type' => 'text',
		'size' => 36,
		'maxlength' => 36,
		'note' => T_( 'This is you publisher ID in the format &laquo;xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx&raquo;; which you can find in the code provided by ShareThis' ),
		'valid_pattern' => '#\w{8}-(\w{4}-){3}\w{12}#' ),
	  'services' => array(
		'label' => T_('Comma &laquo;,&raquo; separated list of services (social/sharing sites)'),
		'defaultvalue' => 'reddit,digg,facebook,myspace,delicious,stumbleupon,technorati,google_bmarks,yahoo_bmarks,yahoo_myweb,windows_live,newsvine,meneame',
		'note' => T_( 'Leave empty to use the default list of 20 services' ),
		'size' => 100 ) ) ;
	}
	
	function BeforeEnable()
	{
		return true ;
	}
	
	/* Add needed Javacript to Head section */
	function SkinBeginHtmlHead( & $params )
	{
		$pub = $this->Settings->get( 'publisher' ) ;
		$services = $this->Settings->get( 'services' );
		
		$sharethis_url = "http://w.sharethis.com/button/sharethis.js#tabs=web%2Cpost%2Cemail&amp;charset=utf-8&amp;services=" ;
		$sharethis_url .= urlencode( $services) ;
		$sharethis_url .= '&amp;style=default&amp;publisher=' . $pub ;
		if ( ! $this->is_ie_crap() ) {
		  require_js( $sharethis_url );
		  return true;
		}
		return false;
	}
  
  	//JJR - added event handler
  	/* Event Handler for displaying in skin as widget (or as $Plugins->call_by_code() fxn call) */
	/* NOTE: same as RenderItemAsHtml code, just took global $Item var instead, and removed $content,
			since we no longer need this (content is already rendered before this event handler is called)
	 */
	function SkinTag( $params )
	{
		global $Item, $Blog;
		
		//$content = & $params['data'] ;
		//$item = & $params['Item'] ;
		
		//JJR - comment out these lines so that we can use ShareThis plugin for other pages types besides just Posts (i.e. Podcast)	
		/*	
		if ( $app_version < 2 ) {
		  $item_type = $Item->typ_ID ;
		} else {
		  $item_type = $Item->ptyp_ID ;
		}
		if ( $item_type != 1 ) return false ;	// don't do it for links 	
		*/
		
		//Get Title & URL; depends on whether or not widget is placed into a post.
		//	Use post title/url; otherwise, use blog title/url.
		if( is_object($Item) ) { 
			$title = "'" . $Item->dget( 'title', 'htmlattr' ) . "'" ;
			$url   = "'" . $Item->get_permanent_url() . "'" ;
		}
		else {
			$title 	= "'" . $Blog->get_name() . "'";
			$url 	= "'" . $Blog->get('url') . "'";
		}

		//Denote start of block, passed in param
		echo $params['block_start']."\n";

		//    pre_dump( $params );
		if ( ! $this->is_ie_crap() ) {
			echo  "\n".'<div class="sharethis">
			<script type="text/javascript" language="javascript">
				var object = SHARETHIS.addEntry( {
				  title : '. $title .',
				  url   : '. $url   .'		  
				},
				{ button: true }
				) ;
				
			</script></div>' . "\n" ;  
		}
		
		//Denote end of block, passed in param
		echo $params['block_end']."\n";
		
		return ( true ) ;

	}


	//JJR - not using as renderer, so comment out.
	/* Define HTML Hook */
	/*
	function RenderItemAsHtml( & $params )
	{
		// pre_dump( $params['data'] );
		$this->insert_sharethis_block( & $params ) ;
		return true ;
	}
	*/
	
	//JJR - not using as renderer, so comment out.
	/* Define XML Hook. Do nothing */
	/*
	function RenderItemAsXml ( & $params )
	{
		return true ;
	}
	*/
	
	//JJR - not using as renderer, so comment out.
	/*
	function insert_sharethis_block( & $params )
	{
		global $app_version;
		
		$content = & $params['data'] ;
		$item = & $params['Item'] ;
		
		if ( $app_version < 2 ) {
		  $item_type = $item->typ_ID ;
		} else {
		  $item_type = $item->ptyp_ID ;
		}
		//JJR - comment out this line so that we can use ShareThis plugin for other pages types besides just Posts (i.e. Podcast)
		//if ( $item_type != 1 ) // don't do it for links
		//	 return false ;
		
		$title = "'" . $item->dget( 'title', 'htmlattr' ) . "'" ;
		$url   = "'" . $item->get_permanent_url() . "'" ;
		
		//    pre_dump( $params );
		if ( ! $this->is_ie_crap() ) {
		  $content .=  "\n".'<div class="sharethis">
			<script type="text/javascript" language="javascript">
			  SHARETHIS.addEntry( {
				title : '. $title .',
				  url   : '. $url   .'}, 
				{ button: true }
			  ) ;
			</script></div>' . "\n" ;    
		}
		
		return ( true ) ;
	}//end function insert_sharethis_block
	*/	
		
	function is_ie_crap() {
		$match = preg_match( '/MSIE [56]\.\d/', $_SERVER['HTTP_USER_AGENT'] );
		return ( $match );
	}


} // end class

/****** CHANGELOG *****
 ****** END CHANGELOG *****/
/* vi: ts=2 sw=2 et nu nowrap
 */
?>
